@@ -2,7 +2,7 @@ package Test2::API::Breakage;
 use strict;
 use warnings;
 
-our $VERSION = '1.302085';
+our $VERSION = '1.302096';
 
 
 use Test2::Util qw/pkg_to_file/;
@@ -33,6 +33,9 @@ sub upgrade_required {
         'Test::UseAllModules'     => '0.14',
         'Test::More::Prefix'      => '0.005',
 
+        'Test2::Tools::EventDumper' => 0.000007,
+        'Test2::Harness'            => 0.000013,
+
         'Test::DBIx::Class::Schema'    => '1.0.9',
         'Test::Clustericious::Cluster' => '0.30',
     );
