@@ -2,18 +2,11 @@ package Test2::Event::Bail;
 use strict;
 use warnings;
 
-our $VERSION = '1.302071';
+our $VERSION = '1.302096';
 
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
-use Test2::Util::HashBase qw{reason};
-
-sub callback {
-    my $self = shift;
-    my ($hub) = @_;
-
-    $hub->set_bailed_out($self);
-}
+use Test2::Util::HashBase qw{reason buffered};
 
 # Make sure the tests terminate
 sub terminate { 255 };
@@ -32,6 +25,20 @@ sub summary {
 
 sub diagnostics { 1 }
 
+sub facet_data {
+    my $self = shift;
+    my $out = $self->common_facet_data;
+
+    $out->{control} = {
+        global    => 1,
+        halt      => 1,
+        details   => $self->{+REASON},
+        terminate => 255,
+    };
+
+    return $out;
+}
+
 1;
 
 __END__
@@ -92,7 +99,7 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2016 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2017 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
