@@ -2,18 +2,29 @@ package Test2::Event::Encoding;
 use strict;
 use warnings;
 
-our $VERSION = '1.302083';
+our $VERSION = '1.302096';
+
+use Carp qw/croak/;
 
 BEGIN { require Test2::Event; our @ISA = qw(Test2::Event) }
 use Test2::Util::HashBase qw/encoding/;
 
 sub init {
     my $self = shift;
-    defined $self->{+ENCODING} or $self->trace->throw("'encoding' is a required attribute");
+    defined $self->{+ENCODING} or croak "'encoding' is a required attribute";
 }
 
 sub summary { 'Encoding set to ' . $_[0]->{+ENCODING} }
 
+sub facet_data {
+    my $self = shift;
+    my $out = $self->common_facet_data;
+    $out->{control}->{encoding} = $self->{+ENCODING};
+    $out->{about}->{details} = $self->summary;
+    return $out;
+}
+
+
 1;
 
 __END__
